**********************************************************************
* Katrin Auspurg & Thomas Hinz (in cooperation with Carsten Sauer)
* Accompanying material for: Factorial Survey Experiments.
* SAGE,  Series: Quantitative Applications in the Social Sciences No. 175, 
* Thousand Oaks, CA: SAGE
* 
* 
* // 2 LABELING OF VARIABLES
*************************************************************************

*****************************************
// #1: LOAD AND PREPARE THE SAMPLE
*****************************************

use random120, clear // if you want to use the random sample 

*use fractionalized120, clear // if you want to use the D-efficient sample produced by the SAS job (3_material)
 
** for the D-efficient sample you should rename "block" to "deck" 
** and "run" to "vignr"

capture rename block deck
capture rename run vignr

** at least for the D-efficient sample the decks have to be randomly sorted.

// For doing so, you can use the following five steps: 
// 1) Reshape the data to a wide format
// 2) Create a new variable which is a random number
// 3) Sort the data set by this random number
// 4) Replace the deck by a running number from 1 to N
// 5) Reshape the data back to a long format 

reshape wide x1-x8,  i(deck) j(vignr)
gen random = runiform()  // variable containing random numbers in range [0 ; 1] 
sort random  // creates a random sorting of your data set
replace deck = _n // replaces the deck with a new number 
reshape long x1 x2 x3 x4 x5 x6 x7 x8,  i(deck) j(vignr)
drop random // we do not need this variable any more


** Assign each vignette an identifier 

gen id_vignette = _n  // creates a variable containing a running number from 1 to N
lab var id_vignette "ID of vignette"
order id_vignette


*****************************************
// # 2 LABELING AND RECODING  
*****************************************

** Prepare the data as you will need them within the data analyses

* Rename variables 

rename x1 sex
rename x2 age
rename x3 degree
rename x4 children 
rename x5 job
rename x6 experience
rename x7 tenure
rename x8 income  

* Labeling of all vignette dimensions 

lab var deck "vignette deck"
lab var vignr "position of vignette within deck"
lab var sex "sex of vignette person"
lab var age "age of vignette person"
lab var degree "degree of vignette person"
lab var children "number of children of vignette person"
lab var job "occupation of vignette person"
lab var experience "job experience of vignette person"
lab var tenure "tenure of vignette person"
lab var income "gross income of vignette person"


** Defining of value labels for ordinal and categorical dimensions; 
** recoding of metric dimensions 

lab define sex 1"male" 2"female"
lab val sex sex

recode age (1=25) (2=30) (3=35) (4=40) (5=45)(6=50) (7=55) (8=60)

lab define degree 1"without vocational training" ///
2"vocational training" 3"university degree"
lab val degree degree
  
recode children (1 2 = 0) (3 = 1) (4 = 2) (5 = 3) (6 = 4)

lab define job 1"unskilled worker" 2"doorman/doorwoman" ///
3"engine driver" 4"clerk" 5 "hairdresser" 6"social worker" /// 
7"software programmer" 8"electrical engineer" ///
9 "manager" 10"medical doctor" 
lab val job job

lab define exp 1"little" 2"much"
lab val experience exp

lab define ten 1"entered recently" 2"entered a long time ago"
lab val tenure ten

recode income (1=500)(2=950)(3=1200) (4=1500) (5=2500) (6=3800) ///
(7=5400) (8=6800) (9=10000) (10=15000)


******************************************* 
// #2: CHECK DATA
******************************************* 

** Labeling OK? 
fre sex - income

** Exclusion of implausible cases OK?  

bysort degree: fre job
bysort job: fre income
assert experience == 2 if tenure == 2


******************************************* 
// #3: SAVE DATA
******************************************* 

save setup, replace

*** !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// Note: You should in any case keep these setup data. 
// Store them safetly and do not overwrite them! 
// And make sure you know which respondent got which vignettes/deck. 
// That is, make sure that you know the IDs of the vignettes and/or decks all 
// respondents rated. 
// You will need this information and the set up data for data analyses. 
*** !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

